pub fn run_command(
cx: &mut Cx,
profile_store: Option<&Value>,
command: &ComputeCommand,
) -> Result<String, ComputeCliError>Expand description
Runs a parsed compute command and returns rendered output.
pub fn run_command(
cx: &mut Cx,
profile_store: Option<&Value>,
command: &ComputeCommand,
) -> Result<String, ComputeCliError>Runs a parsed compute command and returns rendered output.